"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdRecord = void 0;
const db_1 = require("../utils/db");
const error_1 = require("../utils/error");
const uuid_1 = require("uuid");
class AdRecord {
    constructor(obj) {
        if (!obj.name || obj.name.length > 100) {
            throw new error_1.ValidationError('Nazwa ogłoszenia nie może być pusta, ani przekraczać 100 znaków.');
        }
        if (obj.description.length > 1000) {
            throw new error_1.ValidationError('Treść ogłoszenia nie może przekraczać 1000 znaków.');
        }
        if (obj.price < 0 || obj.price > 999999999) {
            throw new error_1.ValidationError('Cena nie może być mniejsza niż 0 lub więszka niż 9.999.999.');
        }
        //@TODO: check if URL is valid!
        if (!obj.url || obj.url.length > 100) {
            throw new error_1.ValidationError('Adres ogłoszenia nie może być pusty, ani przekraczać 100 znaków.');
        }
        if (typeof obj.lat !== 'number' || typeof obj.lon !== 'number') {
            throw new error_1.ValidationError('Nie można zlokalizować ogłoszenia.');
        }
        this.id = obj.id ? obj.id : '';
        this.name = obj.name;
        this.description = obj.description;
        this.price = obj.price;
        this.url = obj.url;
        this.lat = obj.lat;
        this.lon = obj.lon;
    }
    static async getOne(id) {
        const [results] = await db_1.pool.execute("SELECT * FROM `ads` WHERE id = :id", {
            id,
        });
        return results.length === 0 ? null : new AdRecord(results[0]);
    }
    // static async listAll(): Promise<AdRecord[] | []> { // findAll przy '' zwroci cala liste
    //   const [results] = await pool.execute("SELECT * FROM `ads`") as AdRecordResults;
    //
    //   return results.length === 0 ? [] : results.map(obj => new AdRecord(obj));
    // }
    static async findAll(name) {
        const [results] = await db_1.pool.execute("SELECT `id`, `lat`, `lon` FROM `ads` WHERE `name` like :search", {
            search: `%${name}%`,
        });
        return results.length === 0 ? [] : results.map(obj => {
            const { id, lat, lon, } = obj;
            return {
                id, lat, lon,
            };
        });
    }
    async insert() {
        if (!this.id) {
            this.id = (0, uuid_1.v4)();
        }
        else {
            throw new error_1.ValidationError('Cannot insert something that already exists.');
        }
        // await pool.execute("INSERT INTO `ads`(`id`, `name`, `description`, `price`, `url`, `lat`, `lon`) VALUES(:id, :name, :description, :price, :url, :lat, :lon)", {
        //   id: this.id,
        //   name: this.name,
        //   description: this.description,
        //   price: this.price,
        //   url: this.url,
        //   lat: this.lat,
        //   lon: this.lon,
        // });
        await db_1.pool.execute("INSERT INTO `ads`(`id`, `name`, `description`, `price`, `url`, `lat`, `lon`) VALUES(:id, :name, :description, :price, :url, :lat, :lon)", this);
        return this.id;
    }
}
exports.AdRecord = AdRecord;
//# sourceMappingURL=ad.record.js.map