import express, {json, Router} from "express";
import cors from "cors";
import 'express-async-errors';
import { handleError } from "./utils/error";
import rateLimit from "express-rate-limit";
import {adRouter} from "./routers/ad.router";
import {config} from "./config/config";

const app = express();

app.use(cors({
  origin: config.corsOrigin,
}));

app.use(json());

app.use(rateLimit({
  windowMs: 15 * 60 * 1000, // 15minutes
  max: 100, // Limit each ip to 100 request per 'window' (here, per 15minutes);
}));

//deployment

const router = Router();

router.use('/ad', adRouter);

//end

app.use('/api', router);

app.use(handleError);

app.listen(3001, '0.0.0.0', () => {
  console.log('Listening on http://localhost:3001');
});
