import { AdRecord } from "../records/ad.record";
import { pool } from "../utils/db";
import {AdEntity} from "../types";

let ad: AdRecord;
let ad2: AdRecord;

beforeAll(async () => {
  ad = new AdRecord({
    name: 'Testowa',
    description: 'dsasadsda',
    url: 'https://onet.pl/',
    price: 0,
    lat: 0,
    lon: 0,
  });
  ad2 = new AdRecord({
    name: 'Testowa',
    description: 'dsasadsda',
    url: 'https://onet.pl/',
    price: 0,
    lat: 0,
    lon: 0,
  });
});

afterAll(async () => {
  await pool.end();
});

test('AdRecord returns data from database for one entry.', async () => {
  const add = await AdRecord.getOne('abc');

  expect(add).toBeDefined();
  expect(add.id).toBe('abc');
  expect(add.name).toBe('Test');
});

test('AdRecord returns null from database for unexisting entry.', async () => {
  const add = await AdRecord.getOne('...');

  expect(add).toBeNull();
});

// test('When database is null ListAll returns empty array', async () => {
//   const ads = await AdRecord.listAll();
//
//   expect(ads).toEqual([]);
// });

test ('FindAll returns small amount of data.', async () => {
  const ads = await AdRecord.findAll('');
  expect(ads).not.toEqual([]);
  expect((ads[0] as AdEntity).price).toBeUndefined();
  expect((ads[0] as AdEntity).description).toBeUndefined();

});

test('Insert method should return new id', async () => {
  const id = await ad.insert();

  expect(id).toBeDefined();
  expect(typeof id).toBe('string');
});

test('Insert inserts data to database', async () => {
  const id = await ad2.insert();

  const foundAd = await AdRecord.getOne(id);

  expect(foundAd).toBeDefined();
  expect(foundAd).not.toBeNull();
  expect(foundAd.id).toBe(id);
});